import React from 'react';
import { PropsWithMetadata } from '@highlight-ui/utils-commons';
import { IconColorToken } from '@highlight-ui/icon';
import { ButtonType, ButtonState, ButtonVariant } from './types';
declare type RequireOnlyOne<T, Keys extends keyof T = keyof T> = Pick<T, Exclude<keyof T, Keys>> & {
    [K in Keys]-?: Required<Pick<T, K>> & Partial<Record<Exclude<Keys, K>, undefined>>;
}[Keys];
export declare type IconButtonRef = React.Ref<HTMLButtonElement>;
export declare type IconButtonProps = RequireOnlyOne<React.PropsWithChildren<PropsWithMetadata<{
    /** Allows providing a custom class name */
    className?: string;
    /** Determines the state of the button */
    buttonState?: ButtonState;
    /** Provides the icon by icon's name */
    icon: string;
    /** Specify a color of the icon */
    color?: IconColorToken;
    /**
     * @deprecated This prop has been replaced by 'aria-label' and will be removed in an upcoming release
     */
    ariaLabel: string;
    /** A callback that will be fired ones the button is clicked */
    onClick?: React.MouseEventHandler;
    /** Allows providing the custom CSS */
    style?: React.CSSProperties;
    /** Tab index HTML property */
    tabIndex?: number;
    /**
     * @deprecated This prop has been replaced by variant and will be removed in an upcoming release.
     */
    theme?: ButtonVariant;
    /** Allows specifying the styling of the button */
    variant?: ButtonVariant;
    /** Button Type HTML property */
    type?: ButtonType;
}>> & Omit<React.ComponentPropsWithoutRef<'button'>, 'disabled'>, 'ariaLabel' | 'aria-label'>;
declare const IconButton: React.ForwardRefExoticComponent<IconButtonProps & React.RefAttributes<HTMLButtonElement>>;
export default IconButton;
